package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import java.util.Enumeration;

public class CertificatePair extends ASN1Encodable {
   private X509CertificateStructure forward;
   private X509CertificateStructure reverse;

   public static CertificatePair getInstance(Object obj) {
      if (obj != null && !(obj instanceof CertificatePair)) {
         if (obj instanceof ASN1Sequence) {
            return new CertificatePair((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (CertificatePair)obj;
      }
   }

   private CertificatePair(ASN1Sequence seq) {
      if (seq.size() != 1 && seq.size() != 2) {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      } else {
         Enumeration seq1 = seq.getObjects();

         while(seq1.hasMoreElements()) {
            ASN1TaggedObject var2;
            if ((var2 = ASN1TaggedObject.getInstance(seq1.nextElement())).getTagNo() == 0) {
               this.forward = X509CertificateStructure.getInstance(var2, true);
            } else {
               if (var2.getTagNo() != 1) {
                  throw new IllegalArgumentException("Bad tag number: " + var2.getTagNo());
               }

               this.reverse = X509CertificateStructure.getInstance(var2, true);
            }
         }

      }
   }

   public CertificatePair(X509CertificateStructure forward, X509CertificateStructure reverse) {
      this.forward = forward;
      this.reverse = reverse;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      X509CertificateStructure var2;
      if ((var2 = this.forward) != null) {
         DERTaggedObject var3;
         var3 = new DERTaggedObject.<init>(0, var2);
         var1.add(var3);
      }

      X509CertificateStructure var4;
      if ((var4 = this.reverse) != null) {
         DERTaggedObject var5;
         var5 = new DERTaggedObject.<init>(1, var4);
         var1.add(var5);
      }

      return new DERSequence(var1);
   }

   public X509CertificateStructure getForward() {
      return this.forward;
   }

   public X509CertificateStructure getReverse() {
      return this.reverse;
   }
}
